贫民窟的百万富翁 (豆瓣)
Description: 贫民窟的百万富翁电影简介和剧情介绍,贫民窟的百万富翁影评、图片、预告片、影讯、论坛、在线购票
Keywords: 贫民窟的百万富翁,Slumdog Millionaire,贫民窟的百万富翁影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.186豆瓣电影Top250

# 贫民窟的百万富翁 Slumdog Millionaire (2008)

导演: 丹尼·博伊尔 / 洛芙琳·坦丹
编剧: 西蒙·博福伊 / 维卡斯·史瓦卢普
主演: 戴夫·帕特尔 / 沙鲁巴·舒克拉 / 亚尼·卡普 / 拉詹德拉纳斯·祖特施 / 吉尼瓦·塔瓦尔 / 芙蕾达·平托 / 伊尔凡·可汗 / 爱资哈尔丁·穆罕默德·伊斯梅尔 / 阿什·马赫什·舍德卡 / 马赫什·曼杰瑞卡 / 麦活·米泰尔
类型: 剧情 / 爱情
官方网站: www.foxsearchlight.com/slumdogmillionaire/
制片国家/地区: 英国
语言: 英语 / 印地语 / 法语 / 德语
上映日期: 2009-03-26(中国大陆) / 2008-08-30(特柳赖德电影节) / 2009-01-09(英国)
片长: 120分钟
又名: 一百万零一夜(港) / 贫民百万富翁(台) / 贫民富翁 / 山寨富翁 / 阳光小阿三(豆友译名)
IMDb: tt1010048
豆瓣评分
引用
8.6
715918人评价
5星
43.0%
4星
44.8%
3星
11.3%
2星
0.7%
1星
0.2%
好于 96% 剧情片
好于 98% 爱情片
想看 看过
评价:
推荐

## 贫民窟的百万富翁的剧情简介 · · · · · ·

2006年，印度孟买。
印度青年杰玛•马利克（戴夫•帕特尔饰）还差一个问题就能赢得2千万卢比。他是怎么做到的？A：他作弊；B：他幸运；C：他是天才；D：一切命中注定。
这是《谁想成为百万富翁》电视猜谜节目的人生版。杰玛•马利克在已经赢得1千万卢比的情况下被警方以欺诈罪逮捕，严刑拷问下杰玛说出他获得1千万卢比的真相——他确实知道答案，但他只知道这些！
出身贫民窟的杰玛年幼就生活艰苦，他与哥哥沙里姆、少女拉媞卡(芙蕾达•平托饰)三人却一起经历了几十年印度的变迁。之前每一个问题，都好像是杰玛的记忆碎片，牵动他关于亲情、爱情与人生的回忆。
而现在，杰玛一方面要洗清自己的犯罪嫌疑，一方面要拯救与拉媞卡的爱。在金钱与爱之前，杰玛能够沉着冷静，选择出正确的答案吗？ ©豆瓣

## 贫民窟的百万富翁的演职员 · · · · · · ( 全部 19 )

- 丹尼·博伊尔 导演
- 洛芙琳·坦丹 Co-director: India
- 戴夫·帕特尔 饰 Older Jamal
- 沙鲁巴·舒克拉 饰 Sergeant Srinivas
- 亚尼·卡普 饰 Prem
- 拉詹德拉纳斯·祖特施 饰 Director

## 贫民窟的百万富翁的视频和图片 · · · · · · ( 预告片2 | 视频评论1 · 添加 | 图片259 · 添加 )

## 贫民窟的百万富翁的获奖情况 · · · · · · ( 全部 )

- 第81届奥斯卡金像奖
- 最佳影片
- 克里斯蒂安·科尔森

- 第66届金球奖
- 电影类 最佳剧情片

- 第22届欧洲电影奖
- 观众选择奖

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  阿甘正传

  荒岛余生

  肖申克的救赎

  当幸福来敲门

  国王的演讲

  百万美元宝贝

  三傻大闹宝莱坞

  泰坦尼克号

  幸福终点站

我要写短评

## 贫民窟的百万富翁的短评 · · · · · · ( 全部 104005 条 )

热门 / 最新 / 好友

### 3420 有用 孬爷爷 看过 2009-02-27 23:19:52

杰玛在老大家中劝拉媞卡跟他一起逃走。 拉媞卡：那我们靠什么生活？ 杰玛：爱。 这就是现实中爱情和电影中爱情的差距。

### 1079 有用 镜听 看过 2009-09-05 23:54:26

想了想，还是给了四星——其实我觉得它没有那么好。动人的音乐，流畅的节奏，美丽的画面——纵然肮脏也是美丽的，自始至终都充满了那种顽强的，不可遏止的生命力。 但还是觉得……无论如何都有着欧美导演看东方那种猎奇的意思。这种“猎奇”对我们来说其实也是一样——繁华与污秽并存的孟买，阳光尘土中的泰姬陵，黑暗的街巷，垃圾堆上的贫民窟……包含的元素和符号太多了。固然有着野心和足够的手段，但同时也会冲散很多东西。 ... 想了想，还是给了四星——其实我觉得它没有那么好。动人的音乐，流畅的节奏，美丽的画面——纵然肮脏也是美丽的，自始至终都充满了那种顽强的，不可遏止的生命力。 但还是觉得……无论如何都有着欧美导演看东方那种猎奇的意思。这种“猎奇”对我们来说其实也是一样——繁华与污秽并存的孟买，阳光尘土中的泰姬陵，黑暗的街巷，垃圾堆上的贫民窟……包含的元素和符号太多了。固然有着野心和足够的手段，但同时也会冲散很多东西。 大概还是心存警惕。不过无论如何，丹导还是有两把刷子的……这年头会讲故事的导演已经不多了。 (展开)

### 2583 有用 掀桌超人｜2U4U 看过 2010-05-23 13:26:03

得2000万的时候全场欢呼，我却哭了，为他哥。life is shit, but god is great.

### 1167 有用 Lucifer 看过 2012-11-07 01:23:04

贾米尔和他的哥哥不是两个个体，而是人在苦难环境中的两种选择，一个始终怀有赤子之心、爱心、同情心，相信奇迹、美丽、爱情等一切美好的东西，一个被迫选择用暴力和残酷将自己武装。这不是人的错，而是时代的悲剧，即使如此，在黑暗的世界中贾米尔发出的人性光芒如同正午的阳光一样耀眼得让人不能直视

### 738 有用 影志 看过 2008-12-29 22:50:48

just a love story again 基本上就是：《上帝之城》+《猜火车》+《阿甘正传》+《开心辞典》！本片又名：山寨富翁 / 阳光小阿三 囧！

> 更多短评 104005条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 贫民窟的百万富翁的影评 · · · · · · ( 全部 2887 条 )

热门 / 最新 / 好友
谁淫荡呀你淫荡 2009-01-16 02:59:59

## 你们看懂了吗？！他哥哥才是闪光点！

1、下雨时，主角和哥哥在集装箱里睡觉，主角让那女孩进来，可哥哥不肯，理由：“她会招来警察”，不过在主角一再要求下，哥哥还是默许了，注意，哥哥睡觉时是睁着眼的，那眼神有点恐怖。。。 2、主角和哥哥跳上火车逃跑时，哥哥故意放开了那女孩的手，说她会拖累自己。 3、哥... (展开)
6142 399 1194回应 收起
艾小柯 2008-12-19 11:41:42

## 一歌到底，谁解我心

我是一个偏爱悲剧的人。 比较喜剧的圆满，悲剧的残缺更让人思考，它既是故事的终结，又是新一层精神王国的起点。最优秀悲剧的力量往往不可限量，莎士比亚的《李尔王》，雨果的《巴黎圣母院》，托尔斯泰的《安娜卡列尼娜》，而曹老一部《红楼梦》更沦陷了多少代的文学好青年，... (展开)
2198 175 295回应 收起
丁小云 2009-02-26 20:29:27

## 什么是比爱情更值得我们去追求的东西

在没看《贫民窟的百万富翁》之前，我以为它会是一把解剖社会病灶的手术刀。我之所以会这样想，是因为中国的一些“公共知识分子”都在大力推荐本片，但看完之后，我才发现这部电影并不是一把手术刀，而只是一部城市童话。 这部电影我是和老婆一起看的，其中印象比较深刻的对话就... (展开)
1665 190 343回应 收起
闲蛋| 唾面自干 2009-01-04 15:16:42

## 印度人民的感情被伤害了

这篇影评可能有剧透

先学这部片子，来个有奖问答。答对者可领取我个人签名照一张。 提问：下面哪一句出自中国著名新闻发言人之口： a.......不仅干涉了中国内政，而且严重伤害了中国人民的感情。中方对此表示强烈不满和坚决反对。 b.据我了解，很多人不喜欢这类音乐，因为它太嘈杂，噪音太大。... (展开)
1007 184 300回应 收起
绿脚趾 2010-07-02 16:23:36

## 这一切真的是命中注定吗？

Mumbai,2006 Jamal Malik is one question away from winning 20 million rupees. How did he do it? A:He cheated B:He`s lucky C:He`s a genius D:It is written 要回答这个问题我们必须回顾电视猜谜节目"Who Wants To Be A Millionaire"为挑战者准备的全部九道选择题，看看... (展开)
616 68 41回应 收起
阑夕 2009-01-24 20:46:59

## 贫民窟的百万富翁

文/阑夕 http://blog.sina.com.cn/foxshuo 《贫民窟的百万富翁》播放到剧情结束，字幕组善意的在画面上加上了提示字幕：“别走开，稍后还有舞蹈”。我换了个姿势，让自己更加舒服的靠在椅背上，兴致勃勃的看着印度风情的现代舞在火车站台上演，我想，2009年的奥斯卡搞不好能够... (展开)
306 50 87回应 收起
Ruby超人小姐 2009-03-03 07:05:29

## 这世界充满泪水非你能知晓

前几天我还和人半开玩笑半正经地说，我小时候最大的愿望是做黑社会老大的情妇。黑社会老大有权有势又讲义气，有他罩着谁敢欺负我呀，到时候必要恃宠而骄要风要雨不可一世。 看完【Slumdog Millionaire】，这个肤浅的愿望就哗啦一下碎掉了。少女拉提卡倒真是黑帮老大的情妇，但... (展开)
207 13 48回应 收起
柏邦妮 2009-02-22 09:26:34

## 也许我们最终会走到自己的反面

又看《贫民窟中的百万富翁》，失望扩大。 主要原因是，我得知导演是丹尼尔 鲍伊，他是《浅坟》和《猜火车》的导演， 编剧则是《光猪六壮士》的编剧。 如果是一对拍MV起家的新人，有这样的电影，当然是一个惊喜， 但是是这二位，不免有些失望。 记得三年前我在济南，和一群领导... (展开)
105 31 47回应 收起
花开落年复年 2017-11-12 22:47:19

## 浪漫传奇——《贫民窟的百万富翁》

近两年头脑风暴类的竞技综艺不绝于眼，而印度影片《贫民窟的百万富翁》就是以这样的开场来介绍贾马尔戏剧性的人生。完全不同性格的兄弟的人生历程贯穿了全片，通过没受过教育的弟弟贾马尔的戏剧性回忆闪回，揭露出印度底下层社会遭遇的种种不公平待遇以及小人物的挣扎与反抗，... (展开)
86 1 1回应 收起
緩慢 2009-03-03 13:16:21

## 需要夢想又害怕夢想

《一百萬零一夜》（下稱《一》）在奧斯卡贏得最佳導演、最佳電影及最佳改編劇本等八項大獎；其實在奧斯卡揭曉之前，香港不少傳媒早已為電影造勢，高唱電影是「海嘯之光」，說主角Jamal「人窮志不窮」，「振奮人心」云云。大家心領神會：有些人大概覺得艱難時期特別需要神話，於... (展开)
64 7 13回应 收起

> 更多影评 2887篇

添加新讨论

## 讨论区 · · · · · ·

Billionaire | 来自Yolaine- |  | 2022-11-21 00:45:40
这里可算是让我看见了豆瓣影评的水平 | 来自沧海 | 1 回应 | 2022-10-30 22:34:33
本片敢于直面印度贫民窟的种种不堪 | 来自黑超秘客 | 5 回应 | 2022-10-24 01:40:34
二刷还是很激动！ | 来自女王の专属领地 |  | 2022-10-19 21:21:04
虐待男主的印度警察看起来很眼熟！是谁？ | 来自MrZongli | 3 回应 | 2022-10-07 02:50:35

> 去这部影片的讨论区（全部874条）

## 关于《贫民窟的百万富翁》的问题 · · · · · · ( 全部23个 )

- 孟买询问latika去处的地下通道口喷出白烟的机器是什么？ 5人回答
- 关于板球的那个问题，主角为什么能肯定A不是？ 4人回答

> 全部23个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【励志电影】 (影志)
- 【英国制造】 (影志)
- 【城市印象】— 跟着电影去旅行 (狷介有乌青)

## 谁在看这部电影 · · · · · ·

- 真的没有在摸鱼
  3分钟前 看过
- 实如水面
  5分钟前 看过
- 杨坚强
  10分钟前 看过

1173906人看过 / 211848人想看

订阅贫民窟的百万富翁的评论:
feed: rss 2.0